==> zio-aws-codecommit_3-5.17.104.12-sources.jar: zio/aws/codecommit/model/ListApprovalRuleTemplatesResponse.scala <==
package zio.aws.codecommit.model
import zio.aws.codecommit.model.primitives.{NextToken, ApprovalRuleTemplateName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListApprovalRuleTemplatesResponse(
    approvalRuleTemplateNames: Option[Iterable[ApprovalRuleTemplateName]] =
      None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codecommit.model.ListApprovalRuleTemplatesResponse = {
    import ListApprovalRuleTemplatesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codecommit.model.ListApprovalRuleTemplatesResponse
      .builder()
      .optionallyWith(
        approvalRuleTemplateNames.map(value =>
          value.map { item =>
            ApprovalRuleTemplateName.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.approvalRuleTemplateNames)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.codecommit.model.ListApprovalRuleTemplatesResponse.ReadOnly =
    zio.aws.codecommit.model.ListApprovalRuleTemplatesResponse
      .wrap(buildAwsValue())
}
object ListApprovalRuleTemplatesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codecommit.model.ListApprovalRuleTemplatesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codecommit.model.ListApprovalRuleTemplatesResponse =
      zio.aws.codecommit.model.ListApprovalRuleTemplatesResponse(
        approvalRuleTemplateNames.map(value => value),
        nextToken.map(value => value)
      )
    def approvalRuleTemplateNames: Option[List[ApprovalRuleTemplateName]]
    def nextToken: Option[NextToken]
    def getApprovalRuleTemplateNames
        : ZIO[Any, AwsError, List[ApprovalRuleTemplateName]] = AwsError
      .unwrapOptionField("approvalRuleTemplateNames", approvalRuleTemplateNames)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codecommit.model.ListApprovalRuleTemplatesResponse
  ) extends zio.aws.codecommit.model.ListApprovalRuleTemplatesResponse.ReadOnly {
    override val approvalRuleTemplateNames
        : Option[List[ApprovalRuleTemplateName]] = scala
      .Option(impl.approvalRuleTemplateNames())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codecommit.model.primitives.ApprovalRuleTemplateName(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.codecommit.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codecommit.model.ListApprovalRuleTemplatesResponse
  ): zio.aws.codecommit.model.ListApprovalRuleTemplatesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-codecommit_3-5.17.170.1-sources.jar: zio/aws/codecommit/model/ListApprovalRuleTemplatesResponse.scala <==
package zio.aws.codecommit.model
import zio.aws.codecommit.model.primitives.{NextToken, ApprovalRuleTemplateName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ListApprovalRuleTemplatesResponse(
    approvalRuleTemplateNames: Optional[Iterable[ApprovalRuleTemplateName]] =
      Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codecommit.model.ListApprovalRuleTemplatesResponse = {
    import ListApprovalRuleTemplatesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codecommit.model.ListApprovalRuleTemplatesResponse
      .builder()
      .optionallyWith(
        approvalRuleTemplateNames.map(value =>
          value.map { item =>
            ApprovalRuleTemplateName.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.approvalRuleTemplateNames)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.codecommit.model.ListApprovalRuleTemplatesResponse.ReadOnly =
    zio.aws.codecommit.model.ListApprovalRuleTemplatesResponse
      .wrap(buildAwsValue())
}
object ListApprovalRuleTemplatesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codecommit.model.ListApprovalRuleTemplatesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codecommit.model.ListApprovalRuleTemplatesResponse =
      zio.aws.codecommit.model.ListApprovalRuleTemplatesResponse(
        approvalRuleTemplateNames.map(value => value),
        nextToken.map(value => value)
      )
    def approvalRuleTemplateNames: Optional[List[ApprovalRuleTemplateName]]
    def nextToken: Optional[NextToken]
    def getApprovalRuleTemplateNames
        : ZIO[Any, AwsError, List[ApprovalRuleTemplateName]] = AwsError
      .unwrapOptionField("approvalRuleTemplateNames", approvalRuleTemplateNames)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codecommit.model.ListApprovalRuleTemplatesResponse
  ) extends zio.aws.codecommit.model.ListApprovalRuleTemplatesResponse.ReadOnly {
    override val approvalRuleTemplateNames
        : Optional[List[ApprovalRuleTemplateName]] = zio.aws.core.internal
      .optionalFromNullable(impl.approvalRuleTemplateNames())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codecommit.model.primitives.ApprovalRuleTemplateName(item)
        }.toList
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.codecommit.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codecommit.model.ListApprovalRuleTemplatesResponse
  ): zio.aws.codecommit.model.ListApprovalRuleTemplatesResponse.ReadOnly =
    new Wrapper(impl)
}
